==> driza-0.5.2.tar.gz: driza-0.5.2/Driza/dialogs/dseleccionvar.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

#Copyright (C) 2006  Inmaculada Luengo Merino, Néstor Arocha Rodríguez

#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

from Driza.ui.dialogos.dseleccionvar import DialogoSeleccionVariables
from qt import *


#TODO: Clases candidatas a especializacion

#Dialogo de filtrado
#contiene una etiqueta con el nombre del filtro actual: textLabel
#Una caja que muestre las variables posibles:  listBox1
#Boton de acceso rapido a la creación de variables: pushButton1
#Boton de aceptación: pushButton2
#Boton de revocación: pushButton3
#Boton de cancelación: pushButton4

class DSeleccionVar(DialogoSeleccionVariables):
	"""Clase generica para los selectores"""
	def __init__(self,gestor,dato,dcrevar,parent):
		DialogoSeleccionVariables.__init__(self,parent,"DialogoSeleccionVar",0,0)
		self.__dcrevar=dcrevar
		self.gestor=gestor
		self.dato=dato
		self.__conexiones()

	def accept(self):
		"""Esta funcion redefine accept, activando el filtro que el usuario ha seleccionado"""
		if self.listBox1.currentItem()!=-1:
			self.gestor.variable=self.dato.getVar(self.listBox1.currentText().latin1())
		DialogoSeleccionVariables.accept(self)

	def __conexiones(self):
		"""Las conexiones """
		self.connect(self.pushButton1,SIGNAL("clicked()"),self.__dcrevar.show)
		self.connect(self.pushButton2,SIGNAL("clicked()"),self.accept)
		self.connect(self.pushButton3,SIGNAL("clicked()"),self.__desactivarvariable)
		self.connect(self.pushButton4,SIGNAL("clicked()"),self.reject)

	def __inicializarlistbox(self):
		"""Simplemente vacia la listbox"""
		self.listBox1.clear()
		self.listBox1.SelectionMode(QListBox.Single)

	def __desactivarvariable(self):
		"""Desactiva la seleccion"""
		self.gestor.variable=None
		DialogoSeleccionVariables.accept(self)



class DFiltro(DSeleccionVar):
	"""Este dialogo permite al usuario establecer la variable que desea usar como filtro"""
	def __init__(self,gestor,dato,dcrevar,parent):
		"""Inicializa el dialogo"""
		DSeleccionVar.__init__(self,gestor,dato,dcrevar,parent)
		self.textLabel1.setText("Selecciona la Variable")

	#FUNCIONES PUBLICAS

	def show(self):
		"""
		Llama al show de la clase base, pero previamente selecciona en el dialogo la variable que ya actua como filtro
		"""
		self.listBox1.clear()
		for x in self.dato.arrTit("Booleano"):
			self.listBox1.insertItem(x)  # Rellena con los valores actuales
		if self.gestor.variable:
			self.listBox1.setSelected(self.listBox1.findItem(self.gestor.variable.nombre),True)
		DialogoSeleccionVariables.show(self)

	def accept(self):
		"""Esta funcion redefine accept, activando el filtro que el usuario ha seleccionado"""
		DSeleccionVar.accept(self)
		self.parent().show() #Que se muestre el nuevo filtro



class DAgrupacion(DSeleccionVar):
	"""Este dialogo permite al usuario establecer la variable que desea usar como Agrupacion"""
	def __init__(self,gestor,dato,dcrevar,parent):
		"""Inicializa el dialogo"""
		DSeleccionVar.__init__(self,gestor,dato,dcrevar,parent)
		self.textLabel1.setText("Selecciona la Variable de agrupacion")

	#FUNCIONES PUBLICAS

	def show(self):
		"""
		Llama al show de la clase base, pero previamente selecciona en el dialogo la variable que ya actua como agrupación
		"""
		self.listBox1.clear()
		for x in self.dato.arrTit("Entero"):
			self.listBox1.insertItem(x)  # Rellena con los valores actuales
		if self.gestor.variable:
			self.listBox1.setSelected(self.listBox1.findItem(self.gestor.variable.nombre),True)
		DialogoSeleccionVariables.show(self)

==> driza-0.6.1.tar.gz: driza-0.6.1/Driza/dialogs/dseleccionvar.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

#Copyright (C) 2006  Inmaculada Luengo Merino, Néstor Arocha Rodríguez

#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

from Driza.ui.dialogos.dseleccionvar import DialogoSeleccionVariables
from qt import *


#TODO: Clases candidatas a especializacion

#Dialogo de filtrado
#contiene una etiqueta con el nombre del filtro actual: textLabel
#Una caja que muestre las variables posibles:  listBox1
#Boton de acceso rapido a la creación de variables: pushButton1
#Boton de aceptación: pushButton2
#Boton de revocación: pushButton3
#Boton de cancelación: pushButton4

class DSeleccionVar(DialogoSeleccionVariables):
	"""Clase generica para los selectores"""
	def __init__(self,gestor,dato,dcrevar,parent):
		DialogoSeleccionVariables.__init__(self,parent,"DialogoSeleccionVar",0,0)
		self.__dcrevar=dcrevar
		self.gestor=gestor #Publico por el acceso de subclases
		self.dato=dato     #Publico por el acceso de subclases
		self.__conexiones()

	def accept(self):
		"""Esta funcion redefine accept, activando el filtro que el usuario ha seleccionado"""
		if self.listBox1.currentItem()!=-1:
			self.gestor.variable=self.dato.getVar(self.listBox1.currentText().latin1())
		DialogoSeleccionVariables.accept(self)

	def __conexiones(self):
		"""Las conexiones """
		self.connect(self.pushButton1,SIGNAL("clicked()"),self.__dcrevar.show)
		self.connect(self.pushButton2,SIGNAL("clicked()"),self.accept)
		self.connect(self.pushButton3,SIGNAL("clicked()"),self.__desactivarvariable)
		self.connect(self.pushButton4,SIGNAL("clicked()"),self.reject)

	def __inicializarlistbox(self):
		"""Simplemente vacia la listbox"""
		self.listBox1.clear()
		self.listBox1.SelectionMode(QListBox.Single)

	def __desactivarvariable(self):
		"""Desactiva la seleccion"""
		self.gestor.variable=None
		DialogoSeleccionVariables.accept(self)



class DFiltro(DSeleccionVar):
	"""Este dialogo permite al usuario establecer la variable que desea usar como filtro"""
	def __init__(self,gestor,dato,dcrevar,parent):
		"""Inicializa el dialogo"""
		DSeleccionVar.__init__(self,gestor,dato,dcrevar,parent)
		self.textLabel1.setText("Selecciona la Variable")

	#FUNCIONES PUBLICAS

	def show(self):
		"""
		Llama al show de la clase base, pero previamente selecciona en el dialogo la variable que ya actua como filtro
		"""
		self.listBox1.clear()
		for x in self.dato.arrTit("Booleano"):
			self.listBox1.insertItem(x)  # Rellena con los valores actuales
		if self.gestor.variable:
			self.listBox1.setSelected(self.listBox1.findItem(self.gestor.variable.nombre),True)
		DialogoSeleccionVariables.show(self)

	def accept(self):
		"""Esta funcion redefine accept, activando el filtro que el usuario ha seleccionado"""
		DSeleccionVar.accept(self)
		self.parent().grid.show() #Que se muestre el nuevo filtro



class DAgrupacion(DSeleccionVar):
	"""Este dialogo permite al usuario establecer la variable que desea usar como Agrupacion"""
	def __init__(self,gestor,dato,dcrevar,parent):
		"""Inicializa el dialogo"""
		DSeleccionVar.__init__(self,gestor,dato,dcrevar,parent)
		self.textLabel1.setText("Selecciona la Variable de agrupacion")

	#FUNCIONES PUBLICAS

	def show(self):
		"""
		Llama al show de la clase base, pero previamente selecciona en el dialogo la variable que ya actua como agrupación
		"""
		self.listBox1.clear()
		for x in self.dato.arrTit("Entero"):
			self.listBox1.insertItem(x)  # Rellena con los valores actuales
		if self.gestor.variable:
			self.listBox1.setSelected(self.listBox1.findItem(self.gestor.variable.nombre),True)
		DialogoSeleccionVariables.show(self)
